pub async fn resolve_allowed_addresses(
env: &Arc<Env>,
host: &str,
port: u16,
context: &'static str,
) -> Result<Vec<SocketAddr>, Error>Expand description
Resolves host and drops every address covered by APP_BLOCKED_CIDRS, for connections that
cannot be routed through outbound_client and have to dial the returned addresses directly.